package ir.cristiansoft.wallpaper;

import android.app.WallpaperManager;
import android.content.Context;
import android.content.Intent;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.drawable.BitmapDrawable;
import android.graphics.drawable.Drawable;
import android.media.MediaScannerConnection;
import android.net.Uri;
import android.os.Environment;
import android.support.annotation.DrawableRes;
import android.support.v4.content.res.ResourcesCompat;
import android.util.Log;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.OutputStream;

public class FeaturesHelper {
    private static final String TAG = "FeaturesHelper";

    public static boolean setAsWallpaper(Context context, @DrawableRes int id) {
        boolean success=false;
        WallpaperManager wallpaperManager = WallpaperManager.getInstance(context);
        Drawable drawable = ResourcesCompat.getDrawable(context.getResources(), id, null);
        Bitmap bitmap = ((BitmapDrawable) drawable).getBitmap();
        try {
            wallpaperManager.setBitmap(bitmap);
            success=true;
        } catch (IOException e) {
            Log.e(TAG, "setAsWallpaper: " + e.toString());
        }
        return success;
    }

    public static void shareWallpaper(Context context, int wallpaperResourceId) {
        Bitmap bitmap = BitmapFactory.decodeResource(context.getResources(), wallpaperResourceId);
        String path = Environment.getExternalStoragePublicDirectory(Environment.DIRECTORY_PICTURES) + "/wallpaper" + String.valueOf(wallpaperResourceId) + ".jpg";
        OutputStream out = null;
        File file = new File(path);
        try {
            out = new FileOutputStream(file);
            bitmap.compress(Bitmap.CompressFormat.JPEG, 100, out);
            out.flush();
            out.close();
        } catch (Exception e) {
            e.printStackTrace();
        }
        path = file.getPath();
        Uri bmpUri = Uri.parse("file://" + path);
        Intent shareIntent = new Intent(android.content.Intent.ACTION_SEND);
        shareIntent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
        shareIntent.putExtra(Intent.EXTRA_STREAM, bmpUri);
        shareIntent.setType("image/jpg");
        context.startActivity(Intent.createChooser(shareIntent, "Share with"));
    }

    public static boolean downloadWallpaper(Context context, int wallpaperResourceId) {
        boolean downloadedSuccessfully = false;
        Bitmap bm = BitmapFactory.decodeResource(context.getResources(), wallpaperResourceId);
        String extStorageDirectory = Environment.getExternalStorageDirectory().toString();
        File file = new File(extStorageDirectory, "iWallpaper");
        file.mkdirs();
        File imageFile = new File(file, "wallpaper" + String.valueOf(wallpaperResourceId) + ".jpg");
        FileOutputStream outStream = null;
        try {
            outStream = new FileOutputStream(imageFile);
            bm.compress(Bitmap.CompressFormat.JPEG, 100, outStream);
            outStream.flush();
            outStream.close();
            MediaScannerConnection.scanFile(context, new String[]{imageFile.getPath()}, new String[]{"image/jpeg"}, null);
            downloadedSuccessfully = true;
        } catch (FileNotFoundException e) {
            e.printStackTrace();
        } catch (IOException e) {
            e.printStackTrace();
        }
        return downloadedSuccessfully;
    }
}
