package ir.cristiansoft.wallpaper;

import android.content.Context;
import android.content.Intent;
import android.content.res.TypedArray;
import android.support.v7.widget.RecyclerView;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;

import com.squareup.picasso.Picasso;
import java.util.ArrayList;
import java.util.List;

public class WallpaperAdapter extends RecyclerView.Adapter<WallpaperAdapter.WallpaperViewHolder> {

    Context mainContext;
    private List<Integer> wallpapers = new ArrayList<>();

    public WallpaperAdapter(Context context){
        this.mainContext = context;
        setupWallpapers();
    }

    private void setupWallpapers(){
        TypedArray wallpaperList = mainContext.getResources().obtainTypedArray(R.array.wallpapers_id);
        try
        {
            for (int i = 0; i < wallpaperList.length();i++)
            {
                wallpapers.add(wallpaperList.getResourceId(i , -1));
            }
        }
        finally
        {
            wallpaperList.recycle();
        }
    }

    @Override
    public WallpaperViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        return new WallpaperViewHolder(LayoutInflater.from(mainContext).inflate(
                R.layout.custom_item , parent , false));
    }

    @Override
    public void onBindViewHolder(WallpaperViewHolder holder, int position) {
        holder.bindWallpaper(wallpapers.get(position));
    }

    @Override
    public int getItemCount() {
        return wallpapers.size();
    }

    public class WallpaperViewHolder extends RecyclerView.ViewHolder{
        private ImageView imageView;
        public WallpaperViewHolder(View itemView) {
            super(itemView);
            imageView = (ImageView) itemView;
        }

        public void bindWallpaper(final int wallpaperId) {
            Picasso.with(mainContext).load(wallpaperId).into(imageView);
            itemView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    Intent i = new Intent(mainContext , FullscreenActivity.class);
                    i.putExtra("resource_id" , wallpaperId);
                    mainContext.startActivity(i);
                }
            });
        }
    }

}
